@@ -33,26 +33,26 @@ pub fn casecmp(left: &[u8], right: &[u8]) -> Ordering {
 /// ```
 #[inline]
 #[must_use]
-pub fn eq(left: &[u8], right: &[u8]) -> bool {
+pub fn case_eq(left: &[u8], right: &[u8]) -> bool {
     left.eq_ignore_ascii_case(right)
 }
 
 #[cfg(test)]
 mod tests {
-    use super::{casecmp, eq};
+    use super::{case_eq, casecmp};
     use core::cmp::Ordering;
 
     #[test]
     fn compares_symbols_without_regard_to_case() {
-        assert!(!eq(b"abcdef", b"abcde"));
-        assert!(eq(b"aBcDeF", b"abcdef"));
-        assert!(!eq(b"abcdef", b"abcdefg"));
-        assert!(eq(b"abcdef", b"ABCDEF"));
+        assert!(!case_eq(b"abcdef", b"abcde"));
+        assert!(case_eq(b"aBcDeF", b"abcdef"));
+        assert!(!case_eq(b"abcdef", b"abcdefg"));
+        assert!(case_eq(b"abcdef", b"ABCDEF"));
 
-        assert!(matches!(casecmp(b"abcdef", b"abcde"), Ordering::Greater));
-        assert!(matches!(casecmp(b"aBcDeF", b"abcdef"), Ordering::Equal));
-        assert!(matches!(casecmp(b"abcdef", b"abcdefg"), Ordering::Less));
-        assert!(matches!(casecmp(b"abcdef", b"ABCDEF"), Ordering::Equal));
+        assert_eq!(casecmp(b"abcdef", b"abcde"), Ordering::Greater);
+        assert_eq!(casecmp(b"aBcDeF", b"abcdef"), Ordering::Equal);
+        assert_eq!(casecmp(b"abcdef", b"abcdefg"), Ordering::Less);
+        assert_eq!(casecmp(b"abcdef", b"ABCDEF"), Ordering::Equal);
 
         assert_eq!(casecmp(b"abcdef", b"abcde") as i32, 1);
         assert_eq!(casecmp(b"aBcDeF", b"abcdef") as i32, 0);
@@ -77,27 +77,15 @@ mod tests {
         // upper_a_tilde.casecmp(upper_a_umlaut).should_not == 0
         // upper_a_umlaut.casecmp(upper_a_tilde).should_not == 0
         // ```
-        assert!(!eq(lower_a_tilde, lower_a_umlaut));
-        assert!(!eq(lower_a_umlaut, lower_a_tilde));
-        assert!(!eq(upper_a_tilde, upper_a_umlaut));
-        assert!(!eq(upper_a_umlaut, upper_a_tilde));
+        assert!(!case_eq(lower_a_tilde, lower_a_umlaut));
+        assert!(!case_eq(lower_a_umlaut, lower_a_tilde));
+        assert!(!case_eq(upper_a_tilde, upper_a_umlaut));
+        assert!(!case_eq(upper_a_umlaut, upper_a_tilde));
 
-        assert!(!matches!(
-            casecmp(lower_a_tilde, lower_a_umlaut),
-            Ordering::Equal
-        ));
-        assert!(!matches!(
-            casecmp(lower_a_umlaut, lower_a_tilde),
-            Ordering::Equal
-        ));
-        assert!(!matches!(
-            casecmp(upper_a_tilde, upper_a_umlaut),
-            Ordering::Equal
-        ));
-        assert!(!matches!(
-            casecmp(upper_a_umlaut, upper_a_tilde),
-            Ordering::Equal
-        ));
+        assert_ne!(casecmp(lower_a_tilde, lower_a_umlaut), Ordering::Equal);
+        assert_ne!(casecmp(lower_a_umlaut, lower_a_tilde), Ordering::Equal);
+        assert_ne!(casecmp(upper_a_tilde, upper_a_umlaut), Ordering::Equal);
+        assert_ne!(casecmp(upper_a_umlaut, upper_a_tilde), Ordering::Equal);
 
         // -- UTF-8 --
         let upper_a_tilde = "Ã".as_bytes();
@@ -113,27 +101,15 @@ mod tests {
         // upper_a_tilde.casecmp(upper_a_umlaut).should_not == 0
         // upper_a_umlaut.casecmp(upper_a_tilde).should_not == 0
         // ```
-        assert!(!eq(lower_a_tilde, lower_a_umlaut));
-        assert!(!eq(lower_a_umlaut, lower_a_tilde));
-        assert!(!eq(upper_a_tilde, upper_a_umlaut));
-        assert!(!eq(upper_a_umlaut, upper_a_tilde));
+        assert!(!case_eq(lower_a_tilde, lower_a_umlaut));
+        assert!(!case_eq(lower_a_umlaut, lower_a_tilde));
+        assert!(!case_eq(upper_a_tilde, upper_a_umlaut));
+        assert!(!case_eq(upper_a_umlaut, upper_a_tilde));
 
-        assert!(!matches!(
-            casecmp(lower_a_tilde, lower_a_umlaut),
-            Ordering::Equal
-        ));
-        assert!(!matches!(
-            casecmp(lower_a_umlaut, lower_a_tilde),
-            Ordering::Equal
-        ));
-        assert!(!matches!(
-            casecmp(upper_a_tilde, upper_a_umlaut),
-            Ordering::Equal
-        ));
-        assert!(!matches!(
-            casecmp(upper_a_umlaut, upper_a_tilde),
-            Ordering::Equal
-        ));
+        assert_ne!(casecmp(lower_a_tilde, lower_a_umlaut), Ordering::Equal);
+        assert_ne!(casecmp(lower_a_umlaut, lower_a_tilde), Ordering::Equal);
+        assert_ne!(casecmp(upper_a_tilde, upper_a_umlaut), Ordering::Equal);
+        assert_ne!(casecmp(upper_a_umlaut, upper_a_tilde), Ordering::Equal);
     }
 
     #[test]
@@ -152,27 +128,15 @@ mod tests {
         // lower_a_tilde.casecmp(upper_a_tilde).should == 1
         // lower_a_umlaut.casecmp(upper_a_umlaut).should == 1
         // ```
-        assert!(!eq(upper_a_tilde, lower_a_tilde));
-        assert!(!eq(upper_a_umlaut, lower_a_umlaut));
-        assert!(!eq(lower_a_tilde, upper_a_tilde));
-        assert!(!eq(lower_a_umlaut, upper_a_umlaut));
+        assert!(!case_eq(upper_a_tilde, lower_a_tilde));
+        assert!(!case_eq(upper_a_umlaut, lower_a_umlaut));
+        assert!(!case_eq(lower_a_tilde, upper_a_tilde));
+        assert!(!case_eq(lower_a_umlaut, upper_a_umlaut));
 
-        assert!(matches!(
-            casecmp(upper_a_tilde, lower_a_tilde),
-            Ordering::Less
-        ));
-        assert!(matches!(
-            casecmp(upper_a_umlaut, lower_a_umlaut),
-            Ordering::Less
-        ));
-        assert!(matches!(
-            casecmp(lower_a_tilde, upper_a_tilde),
-            Ordering::Greater
-        ));
-        assert!(matches!(
-            casecmp(lower_a_umlaut, upper_a_umlaut),
-            Ordering::Greater
-        ));
+        assert_eq!(casecmp(upper_a_tilde, lower_a_tilde), Ordering::Less);
+        assert_eq!(casecmp(upper_a_umlaut, lower_a_umlaut), Ordering::Less);
+        assert_eq!(casecmp(lower_a_tilde, upper_a_tilde), Ordering::Greater);
+        assert_eq!(casecmp(lower_a_umlaut, upper_a_umlaut), Ordering::Greater);
 
         assert_eq!(casecmp(upper_a_tilde, lower_a_tilde) as i32, -1);
         assert_eq!(casecmp(upper_a_umlaut, lower_a_umlaut) as i32, -1);
@@ -193,27 +157,15 @@ mod tests {
         // lower_a_tilde.casecmp(upper_a_tilde).should == 1
         // lower_a_umlaut.casecmp(upper_a_umlaut).should == 1
         // ```
-        assert!(!eq(upper_a_tilde, lower_a_tilde));
-        assert!(!eq(upper_a_umlaut, lower_a_umlaut));
-        assert!(!eq(lower_a_tilde, upper_a_tilde));
-        assert!(!eq(lower_a_umlaut, upper_a_umlaut));
+        assert!(!case_eq(upper_a_tilde, lower_a_tilde));
+        assert!(!case_eq(upper_a_umlaut, lower_a_umlaut));
+        assert!(!case_eq(lower_a_tilde, upper_a_tilde));
+        assert!(!case_eq(lower_a_umlaut, upper_a_umlaut));
 
-        assert!(matches!(
-            casecmp(upper_a_tilde, lower_a_tilde),
-            Ordering::Less
-        ));
-        assert!(matches!(
-            casecmp(upper_a_umlaut, lower_a_umlaut),
-            Ordering::Less
-        ));
-        assert!(matches!(
-            casecmp(lower_a_tilde, upper_a_tilde),
-            Ordering::Greater
-        ));
-        assert!(matches!(
-            casecmp(lower_a_umlaut, upper_a_umlaut),
-            Ordering::Greater
-        ));
+        assert_eq!(casecmp(upper_a_tilde, lower_a_tilde), Ordering::Less);
+        assert_eq!(casecmp(upper_a_umlaut, lower_a_umlaut), Ordering::Less);
+        assert_eq!(casecmp(lower_a_tilde, upper_a_tilde), Ordering::Greater);
+        assert_eq!(casecmp(lower_a_umlaut, upper_a_umlaut), Ordering::Greater);
 
         assert_eq!(casecmp(upper_a_tilde, lower_a_tilde) as i32, -1);
         assert_eq!(casecmp(upper_a_umlaut, lower_a_umlaut) as i32, -1);
@@ -230,14 +182,8 @@ mod tests {
         for (left, right) in lower.zip(upper) {
             let left = left.encode_utf8(&mut l_buf);
             let right = right.encode_utf8(&mut r_buf);
-            assert!(matches!(
-                casecmp(left.as_bytes(), right.as_bytes()),
-                Ordering::Equal
-            ));
-            assert!(matches!(
-                casecmp(right.as_bytes(), left.as_bytes()),
-                Ordering::Equal
-            ));
+            assert_eq!(casecmp(left.as_bytes(), right.as_bytes()), Ordering::Equal);
+            assert_eq!(casecmp(right.as_bytes(), left.as_bytes()), Ordering::Equal);
         }
     }
 }
